// Showoctocats WebExtension back end

function replaceType(header, type) {
	header.value = header.value.replace(/text\/plain/i, type);
}

function listener(details) {
	if (details.statusCode < 200 || details.statusCode > 299)
		return;

	const regexp = /^https:\/\/raw\.githubusercontent\.com\/([^/?]+\/){3}/i;
	if (!details.url.match(regexp))
		return;

	let changeType = false;

	for (let header of details.responseHeaders) {
		if (!header.name.match(/^Content-Type$/i))
			continue;
		if (!header.value || !header.value.match(/^text\/plain(;|$)/i))
			return;

		changeType = true;

		if (details.url.match(/\.css$/i))
			replaceType(header, "text/css");
		else if (details.url.match(/\.html?$/i))
			replaceType(header, "text/html");
		else if (details.url.match(/\.js$/i))
			replaceType(header, "application/javascript");
		else if (details.url.match(/\.xhtml$/i))
			replaceType(header, "application/xhtml+xml");
		else
			return;
	}

	if (!changeType)
		return;

	for (let header of details.responseHeaders) {
		if (!header.name.match(/^Content-Security-Policy$/i))
			continue;

		let index = details.responseHeaders.indexOf(header);
		details.responseHeaders.splice(index, 1);
		break;
	}

	return {responseHeaders: details.responseHeaders};
}

browser.webRequest.onHeadersReceived.addListener(
	listener,
	{
		urls: ["https://raw.githubusercontent.com/*"],
		types: ["main_frame", "script", "stylesheet"]
	},
	["blocking", "responseHeaders"]
);
